#
# spec file for package amber-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           amber-cli
Version:        1.13.1+git20250329.c2e3bb8
Release:        1.1
Summary:        CLI tool for tenants to use and access Amber services
License:        BSD-3-Clause
URL:            https://github.com/intel/amber-cli
Source:         %{name}-%{version}.tar.xz
Source1:        vendor.tar.zstd
BuildRequires:  zstd
BuildRequires:  golang(API) >= 1.20

%description
CLI tool for tenants to use and access Amber services.
Amber remotely verifies trustworthiness of Intel SGX and Intel TDX TEEs.

All files are stored in user's home directory. Following are the details:
* Configuration: $HOME/.config/tenantctl/config.yaml
* Logs: $HOME/.config/tenantctl/logs/tac.log
* Bin: $HOME/.local/bin/tenantctl

%prep
%autosetup -p1 -a1

%build
# From the Makefile
GITCOMMIT="HEAD"
BUILDDATE="$(TZ=UTC date -d@${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%S%%z)"
VERSION="%{version}"
GOOS=linux CGO_CPPFLAGS="-D_FORTIFY_SOURCE=2" go build \
	   -mod=vendor \
	   -buildmode=pie \
	   -ldflags "-X intel/amber/tac/v1/utils.BuildDate=${BUILDDATE} -X intel/amber/tac/v1/utils.Version=${VERSION} -X intel/amber/tac/v1/utils.GitHash=${GITCOMMIT} -linkmode=external -s -extldflags '-Wl,-z,relro,-z,now'"\
	   -o tenantctl

%install
install -D -m0755 tenantctl %{buildroot}%{_bindir}/tenantctl

%files
%license LICENSE
%doc README.md
%{_bindir}/tenantctl

%changelog
* Tue Apr 29 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1.13.1+git20250329.c2e3bb8 (bsc#1240511, CVE-2025-30204):
  * jwt version upgrade (#174)
  * Update policy size limit to 20k (#173)
  * Update tenant user model with latest changes (#172)
  * Fix/workflow (#171)
  * Upgrade GO version to 1.23.6 (#170)
  * Update golang jwt dependency (#169)
  * Update TMS roles struct (#167)
  * Update jwt dependency version (#165)
  * Add changes to support JWT (#163)
  * Update roles struct to be in sync with TMS (#164)
  * go upgrade to 1.22.7 (#162)
  * CASSINI-22266: Added permissions in ci workflow files (#153)
  * Add check for missing Security.md file (#150)
  * Go version upgrade to 1.22.5 (#148)
  * CLI changes (#140)
  * Bump github.com/hashicorp/go-retryablehttp from 0.7.4 to 0.7.7 (#147)
  * Update product model to include multiple plan IDs (#146)
  * Updated the help section (#145)
  * Mark policy type field as not required (#144)
  * Upgrade/goversion 1.22.3 (#143)
  * Remove policy type and attestation type check for policy creation (#142)
  * Go version upgrade  1.22.2 (#141)
  * Fix error message to include the correct set of characters (#138)
  * UT coverage 80.9%% (#137)
  * Fix push installer workflow (#136)
  * 3rd party versions upgrade (#133)
  * GO version upgrade to 1.22.0 (#132)
  * Fix/go version 1.21.6 (#127)
  * Update API key validation regex as per latest changes (#125)
  * Update API key validation regex as per latest changes (#124)
  * dependency version upgrade (#123)
  * Update tag create model (#121)
  * CASSINI-10113: Add scans in CI (#99)
  * corrected minor check condition (#120)
  * Add check to validate env variable before setting (#119)
  * Add version-check script (#118)
  * Add file path check for invalid characters (#116)
  * Update compoenent version (#117)
  * Update README as per suggestions (#113) (#115)
  * Added HTTP scheme validation to avoid API Key leakage (#108)
  * CASSINI-10987 Golang version upgrade to 1.21.4 (#114)
  * Update policy model as per the latest changes (#109)
  * Remove branch info from on schedule (#106)
  * Add BDBA scan to CI (#104)
  * Update CLI URL (#105)
  * updated licenses (#102)
  * Updated version of all components to v1.0.0 for GA (#100)
  * Validate the email id input before requesting list of users (#98)
  * Remove redundant print statements (#97)
  * Request ID and trace ID should be visible on the console for errors as well (#96)
  * Update sample policy as per token profile update changes (#95)
  * Update CLI name from tenantclt to inteltrustauthority (#93)
  * Update the headers for request and trace id (#94)
  * cassini-9466-Go version update to 1.20.6 (#91)
  * Add retry logic to client in tenant CLI (#92)
  * Add request-id optional parameter for each command (#90)
* Sat Nov 11 2023 Bernhard Wiedemann <bwiedemann@suse.de>
- Override build date with SOURCE_DATE_EPOCH (boo#1047218)
* Wed Oct  4 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Drop Requires: golang-packaging. The recommended Go toolchain
    dependency expression is BuildRequires: golang(API) >= 1.x or
    optionally the metapackage BuildRequires: go
  * Update to BuildRequires: golang(API) >= 1.20 matching go.mod
* Tue Oct  3 2023 aplanas@suse.com
- Initial package version 0.3.0+git20230728.955f78d:
  * cassini- 9312 removed docker from TenantCLI (#88) (#89)
  * set MarkFlagRequired for update_tenant_settings (#86)
  * Add compiler flags recommended by SDLE (#85)
  * Add compiler flags recommended by SDLE (#84)
  * Update go mod file (#83)
  * Update policy name error message (#82)
  * added copyright message (#81)
  * Add validations for parameters of each command (#80)
  * Update go version to 1.20.4 (#74)
  * Fix issue with config file unavailability (#76)
